@@ -198,6 +198,7 @@ class TestCase(object):
         self.__testresult = None
         self.__resmgr_session = None
         self.__resmgr = None
+        self.__share_data_mgr = None
         self.__test_doc = None
 
         # 参数相关
@@ -329,12 +330,22 @@ class TestCase(object):
             self.__resmgr_session = self.__resmgr.create_session(self)
         return self.__resmgr_session
 
+    @property
+    def share_data_mgr(self):
+        '''共享数据管理器
+        '''
+        return self.__share_data_mgr
+
+    @share_data_mgr.setter
+    def share_data_mgr(self, share_data_mgr):
+        self.__share_data_mgr = share_data_mgr
+
     @property
     def params_definitions(self):
         return self.__params_definitions
 
     @property
-    def params(self):
+    def qtaf_params(self):
         return self.__params
 
     @property
@@ -356,6 +367,26 @@ class TestCase(object):
                 var_dicts[k] = v
         return var_dicts
 
+    def add_share_data(self, name, value, level=0):
+        '''添加共享数据
+
+        :type name: string
+        :param name: 需要共享的数据名称
+        :param value: 需要共享的数据内容
+        '''
+        if self.share_data_mgr:
+            self.share_data_mgr.set(name, value, level)
+
+    def get_share_data(self, name):
+        '''从内存中获取存储的全局数据，给当前用例使用'''
+        if self.share_data_mgr:
+            return self.share_data_mgr.get(name)
+
+    def remove_share_data(self, name):
+        '''从内存中移除存储的共享数据'''
+        if self.share_data_mgr:
+            return self.share_data_mgr.remove(name)
+
     def add_parameters(self):
         # 用例重写或者不重写
         self.add_params()
@@ -389,7 +420,8 @@ class TestCase(object):
     add_param = add_parameter
 
     def assert_types(self):
-        '''参数校验并设置self.params'''
+        '''参数校验并设置self.qtaf_params
+        '''
         errors = []
         for d_name in self.params_definitions:
             default = self.params_definitions[d_name]["default"]
@@ -454,18 +486,18 @@ class TestCase(object):
                 kwargs = {}
             if not isinstance(kwargs, dict):
                 errors.append("Parameter:{}, param(kwargs) must be dict.".format(d_name))
-            if d_name not in self.params:
+            if d_name not in self.qtaf_params:
                 value = default
                 # 如果是default就不进行校验
             else:
-                value = self.params[d_name]
+                value = self.qtaf_params[d_name]
 
             if value == default:  # 如果值与default相等就不进行校验
                 continue
             # 否则进行校验
             if validation is not None and callable(validation):
                 try:
-                    validation(value, self.params, **kwargs)
+                    validation(value, self.qtaf_params, **kwargs)
                 except Exception as exe:
                     errors.append(
                         "Parameter:{}, value:{}, validation error, detail: {}.".format(d_name, value, str(exe)))
@@ -490,7 +522,7 @@ class TestCase(object):
         self.add_params()  # 添加参数定义
         self.assert_types()  # 参数校验
 
-        temp_data = self.params
+        temp_data = self.qtaf_params
 
         if param_mode == "DATADRIVE":
             if isinstance(self.casedata, dict):
@@ -1189,6 +1221,7 @@ class SeqTestSuite(TestSuite):
         '''
         self._testcases = testcases
         self._resmgr = None
+        self.__share_data_mgr = None
 
     def __iter__(self):
         for it in self._testcases:
@@ -1255,6 +1288,19 @@ class SeqTestSuite(TestSuite):
         for it in self._testcases:
             it.test_resmgr = resmgr
 
+
+    @property
+    def share_data_mgr(self):
+        '''共享数据管理器
+        '''
+        return self.__share_data_mgr
+
+    @share_data_mgr.setter
+    def share_data_mgr(self, share_data_mgr):
+        self.__share_data_mgr = share_data_mgr
+        for it in self._testcases:
+            it._share_data_mgr = share_data_mgr
+
     def dumps(self):
         '''序列化
         '''
